@@ -6,12 +6,23 @@ use warnings;
 
 require Exporter;
 our @ISA       = qw(Exporter);
-our @EXPORT_OK = qw(parse_number_id);
+our @EXPORT_OK = qw(parse_number_id $Pat);
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 our %SPEC;
 
+our $Pat = qr/(?:
+                  [+-]?
+                  (?:
+                      \d{1,2}([.]\d{3})*(?:[,]\d*)? | # indo
+                      \d{1,2}([,]\d{3})*(?:[.]\d*)? | # english
+                      [,.]\d+ |
+                      \d+
+                  )
+                  (?:[Ee][+-]?\d+)?
+              )/x;
+
 sub _clean_nd {
     my $n = shift;
     $n =~ s/\D//;
@@ -68,7 +79,7 @@ Parse::Number::ID - Parse number from Indonesian text
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -92,6 +103,15 @@ unambiguous, e.g.:
 This module does not parse numbers that are written as Indonesian words, e.g.
 "seratus dua puluh tiga" (123). See L<Lingua::ID::Words2Nums> for that.
 
+=head1 VARIABLES
+
+None are exported by default, but they are exportable.
+
+=head2 $Pat (REGEX)
+
+A regex for quickly matching/extracting number from text. It's not 100% perfect
+(the extracted number might not be valid), but it's simple and fast.
+
 =head1 FUNCTIONS
 
 None of the functions are exported by default, but they are exportable.
